@@ -10,7 +10,7 @@ template = re.compile("{{.*?}}")
 def string_params_to_dict(string: str) -> Dict[str, str]:
     params = dict()
     if not string:
-        params
+        return params
     for name_par in string.split(","):
         name, par = name_par.strip().split(":")
         params[name] = par.strip()
