@@ -5,6 +5,7 @@ from hdx.utilities.dateparse import parse_date
 
 from hdx.scraper.base_scraper import BaseScraper
 from hdx.scraper.runner import Runner
+from hdx.scraper.utilities.sources import create_source_configuration
 
 from .conftest import run_check_scraper
 
@@ -308,7 +309,7 @@ class TestScraperGlobal:
         run_check_scraper(name, runner, level_name, headers, values, sources)
 
     def test_get_global_2021(
-        self, cerf_headers, caplog, configuration, fallbacks, fixtures
+        self, cerf_headers, caplog, configuration, fallbacks_json, fixtures
     ):
         BaseScraper.population_lookup = dict()
         today = parse_date("2021-05-03")
@@ -369,85 +370,85 @@ class TestScraperGlobal:
                     "#value+cbpf+funding+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gmempty+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gm0+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gm1+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gm2+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gm3+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cbpf+funding+gm4+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gmempty+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gm0+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gm1+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gm2+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gm3+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
                 (
                     "#value+cerf+funding+gm4+total+usd",
                     "2020-09-01",
                     "CERF and CBPF",
-                    "tests/fixtures/fallbacks.json",
+                    fallbacks_json,
                 ),
             ]
             run_check_scraper(
@@ -554,3 +555,111 @@ class TestScraperGlobal:
             ),
         ]
         run_check_scraper(name, runner, level_name, headers, values, sources)
+
+    def test_get_global_source(self, cerf_headers, configuration):
+        BaseScraper.population_lookup = dict()
+        today = parse_date("2021-05-03")
+        level = "single"
+        level_name = "global"
+        scraper_configuration = configuration[f"scraper_{level_name}"]
+        runner = Runner(configuration["HRPs"], today)
+        runner.add_configurables(
+            scraper_configuration,
+            level,
+            level_name=level_name,
+            source_configuration=create_source_configuration(
+                admin_sources=True
+            ),
+        )
+        name = "cerf2_global"
+        headers = (
+            [cerf_headers[0][0], cerf_headers[0][7]],
+            [cerf_headers[1][0], cerf_headers[1][7]],
+        )
+        values = [
+            {"value": 7811774.670000001},
+            {"value": 89298919.0},
+        ]
+        sources = [
+            (
+                "#value+cbpf+funding+total+usd+global",
+                "2021-05-02",
+                "CBPF",
+                "https://data.humdata.org/dataset/cbpf-allocations-and-contributions",
+            ),
+            (
+                "#value+cerf+funding+total+usd+global",
+                "2021-05-01",
+                "CERF",
+                "https://data.humdata.org/dataset/cerf-covid-19-allocations",
+            ),
+        ]
+        run_check_scraper(name, runner, level_name, headers, values, sources)
+
+        runner = Runner(configuration["HRPs"], today)
+        runner.add_configurables(
+            scraper_configuration,
+            level,
+            level_name=level_name,
+            source_configuration=create_source_configuration(
+                admin_mapping_dict={"global": "globe"}
+            ),
+        )
+        name = "cerf2_global"
+        headers = (
+            [cerf_headers[0][0], cerf_headers[0][7]],
+            [cerf_headers[1][0], cerf_headers[1][7]],
+        )
+        values = [
+            {"value": 7811774.670000001},
+            {"value": 89298919.0},
+        ]
+        sources = [
+            (
+                "#value+cbpf+funding+total+usd+globe",
+                "2021-05-02",
+                "CBPF",
+                "https://data.humdata.org/dataset/cbpf-allocations-and-contributions",
+            ),
+            (
+                "#value+cerf+funding+total+usd+globe",
+                "2021-05-01",
+                "CERF",
+                "https://data.humdata.org/dataset/cerf-covid-19-allocations",
+            ),
+        ]
+        run_check_scraper(name, runner, level_name, headers, values, sources)
+
+        runner = Runner(configuration["HRPs"], today)
+        runner.add_configurables(
+            scraper_configuration,
+            level,
+            level_name=level_name,
+            source_configuration=create_source_configuration(
+                suffix_attribute="world"
+            ),
+        )
+        name = "cerf2_global"
+        headers = (
+            [cerf_headers[0][0], cerf_headers[0][7]],
+            [cerf_headers[1][0], cerf_headers[1][7]],
+        )
+        values = [
+            {"value": 7811774.670000001},
+            {"value": 89298919.0},
+        ]
+        sources = [
+            (
+                "#value+cbpf+funding+total+usd+world",
+                "2021-05-02",
+                "CBPF",
+                "https://data.humdata.org/dataset/cbpf-allocations-and-contributions",
+            ),
+            (
+                "#value+cerf+funding+total+usd+world",
+                "2021-05-01",
+                "CERF",
+                "https://data.humdata.org/dataset/cerf-covid-19-allocations",
+            ),
+        ]
+        run_check_scraper(name, runner, level_name, headers, values, sources)
